<?php

namespace Litecms\ButtonSettings\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\ButtonSettings\Interfaces\ButtonSettingsRepositoryInterface;

class ButtonSettingsPublicController extends BaseController
{
    // use ButtonSettingsWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\ButtonSettings\Interfaces\ButtonSettingsRepositoryInterface $button_settings
     *
     * @return type
     */
    public function __construct(ButtonSettingsRepositoryInterface $button_settings)
    {
        $this->repository = $button_settings;
        parent::__construct();
    }

    /**
     * Show button_settings's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $button_settings = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$button_settings::$button_settings.names'))
            ->view('$button_settings::public.button_settings.index')
            ->data(compact('$button_settings'))
            ->output();
    }

    /**
     * Show button_settings's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $button_settings = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$button_settings::$button_settings.names'))
            ->view('$button_settings::public.button_settings.index')
            ->data(compact('$button_settings'))
            ->output();
    }

    /**
     * Show button_settings.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $button_settings = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$button_settings->name . trans('$button_settings::$button_settings.name'))
            ->view('$button_settings::public.button_settings.show')
            ->data(compact('$button_settings'))
            ->output();
    }

}
