<?php

namespace Litecms\ButtonSettings\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\ButtonSettings\Models\ButtonSettings;

class ButtonSettingsPolicy
{

    /**
     * Determine if the given user can view the button_settings.
     *
     * @param UserPolicy $user
     * @param ButtonSettings $button_settings
     *
     * @return bool
     */
    public function view(UserPolicy $user, ButtonSettings $button_settings)
    {
        if ($user->canDo('button_settings.button_settings.view') && $user->isAdmin()) {
            return true;
        }

        return $button_settings->user_id == user_id() && $button_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can create a button_settings.
     *
     * @param UserPolicy $user
     * @param ButtonSettings $button_settings
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('button_settings.button_settings.create');
    }

    /**
     * Determine if the given user can update the given button_settings.
     *
     * @param UserPolicy $user
     * @param ButtonSettings $button_settings
     *
     * @return bool
     */
    public function update(UserPolicy $user, ButtonSettings $button_settings)
    {
        if ($user->canDo('button_settings.button_settings.edit') && $user->isAdmin()) {
            return true;
        }

        return $button_settings->user_id == user_id() && $button_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given button_settings.
     *
     * @param UserPolicy $user
     * @param ButtonSettings $button_settings
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ButtonSettings $button_settings)
    {
        return $button_settings->user_id == user_id() && $button_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given button_settings.
     *
     * @param UserPolicy $user
     * @param ButtonSettings $button_settings
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ButtonSettings $button_settings)
    {
        if ($user->canDo('button_settings.button_settings.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given button_settings.
     *
     * @param UserPolicy $user
     * @param ButtonSettings $button_settings
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ButtonSettings $button_settings)
    {
        if ($user->canDo('button_settings.button_settings.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
