<?php

namespace Litecms\ButtonSettings\Providers;

use Illuminate\Support\ServiceProvider;

class ButtonSettingsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'button_settings');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'button_settings');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.button_settings', function ($app) {
            return $this->app->make('Litecms\ButtonSettings\ButtonSettings');
        });

        // Bind ButtonSettings to repository
        $this->app->bind(
            'Litecms\ButtonSettings\Interfaces\ButtonSettingsRepositoryInterface',
            \Litecms\ButtonSettings\Repositories\Eloquent\ButtonSettingsRepository::class
        );
        // Bind ButtonSettings to repository
        $this->app->bind(
            'Litecms\ButtonSettings\Interfaces\ButtonSettingsRepositoryInterface',
            \Litecms\ButtonSettings\Repositories\Eloquent\ButtonSettingsRepository::class
        );

        $this->app->register(\Litecms\ButtonSettings\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\ButtonSettings\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.button_settings'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/button_settings.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/button_settings')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/button_settings')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
